<img src="logo_maad.png" alt="drawing" width="600"/>


**scikit-maad** is a modular toolbox to **analyze ecoacoustics datasets** in Python 3. This package was designed to bring flexibility to (1) **find regions of interest**, and (2) to compute **acoustic features** in audio recordings. This workflow opens the possibility to use powerfull **machine learning** algorithms through **scikit-learn**, allowing to identify key patterns in all kind of soundscapes.

## Examples and documentation
- See [Howto notebook](./docs/howto.ipynb) in "docs" directory for detail explanations
- See [Python scripts](./examples/) in "examples" directory for a direct approach of MAAD
- In depth information related to the Multiresolution Analysis of Acoustic Diversity implemented in scikit-maad was published in: Ulloa, J. S., Aubin, T., Llusia, D., Bouveyron, C., & Sueur, J. (2018). [Estimating animal acoustic diversity in tropical environments using unsupervised multiresolution analysis](https://doi.org/10.1016/j.ecolind.2018.03.026). Ecological Indicators, 90, 346–355

## Installation
scikit-learn dependencies:

- Python >= 3.5
- NumPy >= 1.13
- SciPy >= 0.18
- scikit-image >= 0.14
- scikit-learn >= 0.18

## About the authors
This work was done at the Museum National d'Histoire Naturelle (MNHN) in Paris, France. It was initiated by [Juan Sebastian Ulloa](https://www.researchgate.net/profile/Juan_Ulloa) in 2016, supervised by Jérôme Sueur and Thierry Aubin at the [Muséum National d'Histoire Naturelle](http://isyeb.mnhn.fr/fr) and the [Université Paris Saclay](http://neuro-psi.cnrs.fr/) respectively. New features were added by [Sylvain Haupert](https://www.researchgate.net/profile/Sylvain_Haupert) and Chloe Huetz.